@@ -1,5 +1,5 @@
 package Clipboard;
-$Clipboard::VERSION = '0.21';
+$Clipboard::VERSION = '0.22';
 use strict;
 use warnings;
 
@@ -66,9 +66,13 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+Clipboard - Copy and paste with any OS
+
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -90,10 +94,6 @@ clipboards are magical.
 With Clipboard.pm, this magic is now trivial to access,
 in a cross-platform-consistent API, from your Perl code.
 
-=head1 NAME
-
-Clipboard - Copy and paste with any OS
-
 =head1 STATUS
 
 Seems to be working well for Linux, OSX, *BSD, and Windows.  I use it
@@ -119,7 +119,7 @@ See http://www.perl.com/perl/misc/Artistic.html
 L<clipaccumulate(1)>, L<clipbrowse(1)>, L<clipedit(1)>,
 L<clipfilter(1)>, L<clipjoin(1)>
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -156,14 +156,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Clipboard>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Clipboard>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
@@ -235,7 +227,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ryan King <rking@panoptic.com>.
+This software is copyright (c) 2020 by Ryan King <rking@panoptic.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
